@@ -15,6 +15,19 @@ df_spatial.Raster <- function(x, ..., hjust = 0.5, vjust = 0.5, na.rm = FALSE) {
   nbands <- ncol(fused) - 2
   names(fused) <- c("x", "y", paste0("band", seq_len(nbands)))
 
+  # Ensure that a factor raster's values stay factors in `fused`
+  # data.frame, taking levels from second column of RAT
+  if (any(raster::is.factor(x))) {
+    band_names <- names(fused)[-1:-2]
+    for (i in seq_along(band_names)) {
+      if (raster::is.factor(x[[i]])) {
+        rat <- raster::levels(x[[i]])[[1]]
+        fused[[band_names[i]]] <-
+          factor(fused[[band_names[i]]], levels = rat[, 1], labels = rat[, 2])
+      }
+    }
+  }
+
   if (na.rm) {
     for (i in seq_len(nbands)) {
       fused <- fused[!is.na(fused[[paste0("band", i)]]), ]
