@@ -12,10 +12,10 @@
 #' Open Street Map (<https://www.openstreetmap.org/>).
 #'
 #' @examples
-#' load_longlake_data()
+#' load_longlake_data(which = "longlake_waterdf")
 #'
 load_longlake_data <- function(env = parent.frame(), vector_format = c("sf", "sp"),
-                               raster_format = c("raster", "stars", "stars_proxy"),
+                               raster_format = c("raster", "stars", "stars_proxy", "terra"),
                                which = NULL) {
   raster_format <- match.arg(raster_format)
   vector_format <- match.arg(vector_format)
@@ -26,7 +26,7 @@ load_longlake_data <- function(env = parent.frame(), vector_format = c("sf", "sp
     "LongLakeDepthSurvey.shp" = "longlake_depthdf",
     "LongLakeMarshWaterPoly.shp" = "longlake_waterdf",
     "LongLakeMarshRoads.shp" = "longlake_roadsdf",
-    "LongLakeMarshWetlands.shp" = " longlake_marshdf",
+    "LongLakeMarshWetlands.gpkg" = " longlake_marshdf",
     "LongLakeMarshStreams.shp" = "longlake_streamsdf",
     "LongLakeMarshBuildings.shp" = "longlake_buildingsdf"
   )
@@ -73,6 +73,11 @@ load_longlake_data <- function(env = parent.frame(), vector_format = c("sf", "sp
     for(i in seq_along(raster_layers)) {
       env[[raster_layers[i]]] <- stars::read_stars(file.path(longlake_folder, names(raster_layers)[i]), proxy = TRUE)
     }
+  } else if (raster_format == "terra"){
+    for(i in seq_along(raster_layers)) {
+      env[[raster_layers[i]]] <- terra::rast(file.path(longlake_folder, names(raster_layers)[i]))
+    }
+
   }
 }
 
