@@ -1,11 +1,9 @@
 
-context("layer-spatial-bbox")
-
 test_that("bbox functions work", {
   load_longlake_data(which = "longlake_waterdf")
   box <- sf::st_bbox(longlake_waterdf)
-  expect_is(sf_bbox_to_sf(box), "sf")
-  expect_is(sf_bbox_to_sf(box)$geometry, "sfc_POLYGON")
+  expect_s3_class(sf_bbox_to_sf(box), "sf")
+  expect_s3_class(sf_bbox_to_sf(box)$geometry, "sfc_POLYGON")
   expect_identical(sf::st_crs(sf_bbox_to_sf(box)), sf::st_crs(longlake_waterdf))
   expect_identical(sf::st_bbox(sf_bbox_to_sf(box)), box)
 })
@@ -13,8 +11,8 @@ test_that("bbox functions work", {
 test_that("bbox functions work with detail arg", {
   load_longlake_data(which = "longlake_waterdf")
   box <- sf::st_bbox(longlake_waterdf)
-  expect_is(sf_bbox_to_sf(box, detail = 30), "sf")
-  expect_is(sf_bbox_to_sf(box, detail = 30)$geometry, "sfc_POLYGON")
+  expect_s3_class(sf_bbox_to_sf(box, detail = 30), "sf")
+  expect_s3_class(sf_bbox_to_sf(box, detail = 30)$geometry, "sfc_POLYGON")
   expect_identical(
     sf::st_crs(sf_bbox_to_sf(box, detail = 30)),
     sf::st_crs(longlake_waterdf)
@@ -32,14 +30,14 @@ test_that("bbox plotting works", {
 
   load_longlake_data(which = c("longlake_waterdf", "longlake_depthdf"))
 
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "layer_spatial.bbox()",
     ggplot() +
       layer_spatial(sf::st_bbox(longlake_waterdf)) +
       layer_spatial(longlake_depthdf)
   )
 
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     "annotation_spatial.bbox()",
     ggplot() +
       annotation_spatial(sf::st_bbox(longlake_waterdf)) +
